@@ -477,7 +477,7 @@ template<class CHAR>
 ostream&
 operator<<(ostream& s, const CDSString<CHAR>& x)
 {
- if ( ! s.flags()&ios::right )
+ if ( ! (s.flags()&ios::right) )
    for (int i=0 ; i<int(s.width()-x.length()) ; i++)
      s << s.fill();
  s << (const CHAR*)x;
