@@ -11,6 +11,19 @@
  *   not to make any modifications and use it as it stands.
  *
  * $Log: hci.h,v $
+ * Revision 1.17  2009-06-04 22:03:02  schwitrs
+ * added support for internal 3g modem - thanks to Michele Valzelli
+ *
+ * Revision 1.16  2009-06-04 21:13:12  schwitrs
+ * added new fan speed - thanks to the efforts of Rob Rutten
+ * updated argument processing to use numeric specifier >9
+ *
+ * Revision 1.15  2009-02-15 13:38:58  schwitrs
+ * added fan modes. The naming should be rationalized.
+ *
+ * Revision 1.14  2009-01-10 20:39:52  schwitrs
+ * added three new resolutions
+ *
  * Revision 1.13  2008-03-21 02:00:01  schwitrs
  * added HCI_TR_BACKLIGHT
  *
@@ -118,7 +131,8 @@ enum {
 	HCI_LCD_BRIGHTNESS   = 0x002a,
 	HCI_HIBERNATION_INFO = 0x002d,
 	HCI_HIBERNATION_LBA  = 0x002e,
-	HCI_POWER_UP         = 0x0048
+	HCI_POWER_UP         = 0x0048,
+	HCI_WIRELESS         = 0x0056
 };
 
 
@@ -139,7 +153,10 @@ enum {
 	HCI_800_480         = 0x04,
 	HCI_1400_1050       = 0x06,
 	HCI_1600_1200       = 0x07,
-	HCI_1280_600        = 0x08
+	HCI_1280_600        = 0x08,
+	HCI_1280_800        = 0x09,
+	HCI_1440_900        = 0x0a,
+	HCI_1920_1200       = 0x0c
 };
 
 enum {
@@ -172,11 +189,16 @@ enum {
 	    HCI_BUSY            = 0x40,
 };
 enum {
+  HCI_FAN_FAN1       = 0x20, // - on?   0010 0000
+  HCI_FAN_FAN2       = 0x40,  // - off?  0100 0000
   HCI_FAN_LOW        = 0x0080, //1000 0000
   HCI_FAN_HIGH       = 0x00ff, //1111 1111
   HCI_FAN_LOW2       = 0x0030,    //0011 0000
   HCI_FAN_LOW3       = 0x0090, //1001 0000
+  HCI_FAN_LOW4       = 0x18, //0001 0010
   HCI_FAN_HIGH2      = 0x60, //0110 0000
+  HCI_FAN_HIGH1      = 0xc0  // - low3? 1100 0000
+
 };
 
 enum {
