@@ -22,6 +22,11 @@ typedef struct {
 int procAccess(ToshProcInfo* proc);
 int smmAccess(SMMRegisters *regs);
 
+enum { ACCESS_DIRECT, ACCESS_KERNEL };
+extern int accessMode;
+void detAccessMode();
+
+
 #ifdef __cplusplus
 }
 #endif
