@@ -2,6 +2,7 @@
 #include "toshibaIDs.hh"
 
 static ToshibaID idList[] = {
+  {0xe873  ,"Satellite M30"}, 
   {0x0db0  ,"Satellite Pro M30"},
   {0xfc00  ,"Satellite 2140CDS"},
   {0xfc01  ,"Satellite 2670/2675/2715XDVD"},
@@ -55,6 +56,7 @@ static ToshibaID idList[] = {
   {0xfc71  ,"Satellite Pro 6000"},
   {0xfc72  ,"Satellite 1805-S207/S274, 1800-712/814"},
   {0xfc73  ,"Portege 2000"},
+  {0xfc76  ,"DynaBook Satellite 1800"},
   {0xfc77  ,"Satellite 5005-S507"},
   {0xfc78  ,"Tecra 9100"},
   {0xfc79  ,"Satellite TE2000"},
